==> basketball_reference_scraper-1.0.8.tar.gz: basketball_reference_scraper-1.0.8/basketball_reference_scraper/constants.py <==
TEAM_TO_TEAM_ABBR = {
        'ATLANTA HAWKS': 'ATL',
        'ST. LOUIS HAWKS': 'SLH',
        'MILWAUKEE HAWKS': 'MIL',
        'TRI-CITIES BLACKHAWKS': 'TCB',
        'BOSTON CELTICS': 'BOS',
        'BROOKLYN NETS': 'BRK',
        'NEW JERSEY NETS' : 'NJN',
        'NEW YORK NETS' : 'NYN',
        'CHICAGO BULLS': 'CHI',
        'CHARLOTTE HORNETS': 'CHO',
        'CHARLOTTE BOBCATS' : 'CHA',
        'CLEVELAND CAVALIERS': 'CLE',
        'DALLAS MAVERICKS': 'DAL',
        'DENVER NUGGETS': 'DEN',
        'DETROIT PISTONS': 'DET',
        'FORT WAYNE PISTONS': 'FWP',
        'GOLDEN STATE WARRIORS': 'GSW',
        'SAN FRANCISCO WARRIORS': 'SFW',
        'PHILADELPHIA WARRIORS': 'PHI',
        'HOUSTON ROCKETS': 'HOU',
        'SAN DIEGO ROCKETS': 'HOU',
        'INDIANA PACERS': 'IND',
        'LOS ANGELES CLIPPERS': 'LAC',
        'SAN DIEGO CLIPPERS': 'SDC',
        'BUFFALO BRAVES': 'BUF',
        'LOS ANGELES LAKERS': 'LAL',
        'MINNEAPOLIS LAKERS': 'MIN',
        'MEMPHIS GRIZZLIES': 'MEM',
        'VANCOUVER GRIZZLIES' : 'VAN',
        'MIAMI HEAT': 'MIA',
        'MILWAUKEE BUCKS': 'MIL',
        'MINNESOTA TIMBERWOLVES': 'MIN',
        'NEW ORLEANS PELICANS' : 'NOP',
        'NEW ORLEANS/OKLAHOMA CITY HORNETS' : 'NOK',
        'NEW ORLEANS HORNETS' : 'NOH',
        'NEW YORK KNICKS' : 'NYK',
        'OKLAHOMA CITY THUNDER' : 'OKC',
        'SEATTLE SUPERSONICS' : 'SEA',
        'ORLANDO MAGIC' : 'ORL',
        'PHILADELPHIA 76ERS' : 'PHI',
        'SYRACUSE NATIONALS' : 'SYR',
        'PHOENIX SUNS' : 'PHO',
        'PORTLAND TRAIL BLAZERS' : 'POR',
        'SACRAMENTO KINGS' : 'SAC',
        'KANSAS CITY KINGS' : 'KCK',
        'KANSAS CITY-OMAHA KINGS' : 'KCK',
        'CINCINNATI ROYALS' : 'CIN',
        'ROCHESTER ROYALS': 'ROR',
        'SAN ANTONIO SPURS' : 'SAS',
        'TORONTO RAPTORS' : 'TOR',
        'UTAH JAZZ' : 'UTA',
        'NEW ORLEANS JAZZ' : 'NOJ',
        'WASHINGTON WIZARDS' : 'WAS',
        'WASHINGTON BULLETS' : 'WAS',
        'CAPITAL BULLETS' : 'CAP',
        'BALTIMORE BULLETS' : 'BAL',
        'CHICAGO ZEPHYRS' : 'CHI',
        'CHICAGO PACKERS' : 'CHI',

        # DEFUNCT FRANCHISES
        'ANDERSON PACKERS': 'AND',
        'CHICAGO STAGS': 'CHI',
        'INDIANAPOLIS OLYMPIANS': 'IND',
        'SHEBOYGAN RED SKINS': 'SRS',
        'ST. LOUIS BOMBERS': 'SLB',
        'WASHINGTON CAPITOLS' : 'WAS',
        'WATERLOO HAWKS': 'WAT',
        }

==> basketball_reference_scraper-1.0.20.tar.gz: basketball_reference_scraper-1.0.20/basketball_reference_scraper/constants.py <==
TEAM_TO_TEAM_ABBR = {
        'ATLANTA HAWKS': 'ATL',
        'ST. LOUIS HAWKS': 'SLH',
        'MILWAUKEE HAWKS': 'MIL',
        'TRI-CITIES BLACKHAWKS': 'TCB',
        'BOSTON CELTICS': 'BOS',
        'BROOKLYN NETS': 'BRK',
        'NEW JERSEY NETS' : 'NJN',
        'NEW YORK NETS' : 'NYN',
        'CHICAGO BULLS': 'CHI',
        'CHARLOTTE HORNETS': 'CHO',
        'CHARLOTTE BOBCATS' : 'CHA',
        'CLEVELAND CAVALIERS': 'CLE',
        'DALLAS MAVERICKS': 'DAL',
        'DENVER NUGGETS': 'DEN',
        'DETROIT PISTONS': 'DET',
        'FORT WAYNE PISTONS': 'FWP',
        'GOLDEN STATE WARRIORS': 'GSW',
        'SAN FRANCISCO WARRIORS': 'SFW',
        'PHILADELPHIA WARRIORS': 'PHI',
        'HOUSTON ROCKETS': 'HOU',
        'SAN DIEGO ROCKETS': 'HOU',
        'INDIANA PACERS': 'IND',
        'LOS ANGELES CLIPPERS': 'LAC',
        'SAN DIEGO CLIPPERS': 'SDC',
        'BUFFALO BRAVES': 'BUF',
        'LOS ANGELES LAKERS': 'LAL',
        'MINNEAPOLIS LAKERS': 'MIN',
        'MEMPHIS GRIZZLIES': 'MEM',
        'VANCOUVER GRIZZLIES' : 'VAN',
        'MIAMI HEAT': 'MIA',
        'MILWAUKEE BUCKS': 'MIL',
        'MINNESOTA TIMBERWOLVES': 'MIN',
        'NEW ORLEANS PELICANS' : 'NOP',
        'NEW ORLEANS/OKLAHOMA CITY HORNETS' : 'NOK',
        'NEW ORLEANS HORNETS' : 'NOH',
        'NEW YORK KNICKS' : 'NYK',
        'OKLAHOMA CITY THUNDER' : 'OKC',
        'SEATTLE SUPERSONICS' : 'SEA',
        'ORLANDO MAGIC' : 'ORL',
        'PHILADELPHIA 76ERS' : 'PHI',
        'SYRACUSE NATIONALS' : 'SYR',
        'PHOENIX SUNS' : 'PHO',
        'PORTLAND TRAIL BLAZERS' : 'POR',
        'SACRAMENTO KINGS' : 'SAC',
        'KANSAS CITY KINGS' : 'KCK',
        'KANSAS CITY-OMAHA KINGS' : 'KCK',
        'CINCINNATI ROYALS' : 'CIN',
        'ROCHESTER ROYALS': 'ROR',
        'SAN ANTONIO SPURS' : 'SAS',
        'TORONTO RAPTORS' : 'TOR',
        'UTAH JAZZ' : 'UTA',
        'NEW ORLEANS JAZZ' : 'NOJ',
        'WASHINGTON WIZARDS' : 'WAS',
        'WASHINGTON BULLETS' : 'WAS',
        'CAPITAL BULLETS' : 'CAP',
        'BALTIMORE BULLETS' : 'BAL',
        'CHICAGO ZEPHYRS' : 'CHI',
        'CHICAGO PACKERS' : 'CHI',

        # DEFUNCT FRANCHISES
        'ANDERSON PACKERS': 'AND',
        'CHICAGO STAGS': 'CHI',
        'INDIANAPOLIS OLYMPIANS': 'IND',
        'SHEBOYGAN RED SKINS': 'SRS',
        'ST. LOUIS BOMBERS': 'SLB',
        'WASHINGTON CAPITOLS' : 'WAS',
        'WATERLOO HAWKS': 'WAT',
        }
TEAM_SETS = [['STL', 'TRI', 'MLH', 'ATL'],
 ['BOS'],
 ['NJN', 'BRK', 'NYN', 'NJA', 'NYA'],
 ['CHO', 'CHA', 'CHH'],
 ['CHI'],
 ['CLE'],
 ['DAL'],
 ['DEN', 'DNR', 'DNA'],
 ['DET', 'FTW'],
 ['GSW', 'SFW', 'PHW'],
 ['SDR', 'HOU'],
 ['INA', 'IND'],
 ['SDC', 'LAC', 'BUF'],
 ['LAL', 'MNL'],
 ['MEM', 'VAN'],
 ['MIA'],
 ['MIL'],
 ['MIN'],
 ['NOP', 'NOH', 'NOK'],
 ['NYK'],
 ['SEA', 'OKC'],
 ['ORL'],
 ['PHI', 'SYR'],
 ['PHO'],
 ['POR'],
 ['CIN', 'SAC', 'KCO', 'KCK', 'ROC'],
 ['DLC', 'SAA', 'SAS', 'TEX'],
 ['TOR'],
 ['NOJ', 'UTA'],
 ['WSB', 'CHP', 'CAP', 'BAL', 'WAS', 'CHZ']]
